# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Inspector'
prefix = 'inspector'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddAttributesToFindings = Action('AddAttributesToFindings')
AttachAssessmentAndRulesPackage = \
    Action('AttachAssessmentAndRulesPackage')
CreateApplication = Action('CreateApplication')
CreateAssessment = Action('CreateAssessment')
CreateResourceGroup = Action('CreateResourceGroup')
DeleteApplication = Action('DeleteApplication')
DeleteAssessment = Action('DeleteAssessment')
DeleteRun = Action('DeleteRun')
DescribeApplication = Action('DescribeApplication')
DescribeAssessment = Action('DescribeAssessment')
DescribeCrossAccountAccessRole = Action('DescribeCrossAccountAccessRole')
DescribeFinding = Action('DescribeFinding')
DescribeResourceGroup = Action('DescribeResourceGroup')
DescribeRulesPackage = Action('DescribeRulesPackage')
DescribeRun = Action('DescribeRun')
DetachAssessmentAndRulesPackage = \
    Action('DetachAssessmentAndRulesPackage')
GetAssessmentTelemetry = Action('GetAssessmentTelemetry')
ListApplications = Action('ListApplications')
ListAssessmentAgents = Action('ListAssessmentAgents')
ListAssessments = Action('ListAssessments')
ListAttachedAssessments = Action('ListAttachedAssessments')
ListAttachedRulesPackages = Action('ListAttachedRulesPackages')
ListFindings = Action('ListFindings')
ListRulesPackages = Action('ListRulesPackages')
ListRuns = Action('ListRuns')
ListTagsForResource = Action('ListTagsForResource')
LocalizeText = Action('LocalizeText')
PreviewAgentsForResourceGroup = Action('PreviewAgentsForResourceGroup')
RegisterCrossAccountAccessRole = Action('RegisterCrossAccountAccessRole')
RemoveAttributesFromFindings = Action('RemoveAttributesFromFindings')
RetireRulesPackage = Action('RetireRulesPackage')
RunAssessment = Action('RunAssessment')
SetTagsForResource = Action('SetTagsForResource')
StartDataCollection = Action('StartDataCollection')
StopDataCollection = Action('StopDataCollection')
UpdateApplication = Action('UpdateApplication')
UpdateAssessment = Action('UpdateAssessment')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon AppStream'
prefix = 'appstream'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApplication = Action('CreateApplication')
CreateSession = Action('CreateSession')
DeleteApplication = Action('DeleteApplication')
GetApiRoot = Action('GetApiRoot')
GetApplication = Action('GetApplication')
GetApplications = Action('GetApplications')
GetApplicationError = Action('GetApplicationError')
GetApplicationErrors = Action('GetApplicationErrors')
GetApplicationStatus = Action('GetApplicationStatus')
GetSession = Action('GetSession')
GetSessions = Action('GetSessions')
GetSessionStatus = Action('GetSessionStatus')
UpdateApplication = Action('UpdateApplication')
UpdateApplicationState = Action('UpdateApplicationState')
UpdateSessionState = Action('UpdateSessionState')



import unittest

from awacs.aws import Principal


class TestPrincipal(unittest.TestCase):
    def test_wildcard_principal(self):
        p = Principal("*")
        self.assertEqual(p.data, "*")
        with self.assertRaises(ValueError):
            p = Principal("*", "FAIL")

    def test_normal_principal(self):
        p = Principal("AWS", "arn:aws:iam::AccountNumber-WithoutHyphens:root")
        self.assertEqual(
            p.data,
            {'AWS': 'arn:aws:iam::AccountNumber-WithoutHyphens:root'}
        )
        with self.assertRaises(ValueError):
            p = Principal("AWS")



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CloudHSM'
prefix = 'cloudhsm'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateLunaClient = Action('CreateLunaClient')
CreateHapg = Action('CreateHapg')
CreateHsm = Action('CreateHsm')
DeleteLunaClient = Action('DeleteLunaClient')
DeleteHapg = Action('DeleteHapg')
DeleteHsm = Action('DeleteHsm')
DescribeLunaClient = Action('DescribeLunaClient')
DescribeHapg = Action('DescribeHapg')
DescribeHsm = Action('DescribeHsm')
GetConfig = Action('GetConfig')
ListAvailableZones = Action('ListAvailableZones')
ListLunaClients = Action('ListLunaClients')
ListHapgs = Action('ListHapgs')
ListHsms = Action('ListHsms')
ModifyLunaClient = Action('ModifyLunaClient')
ModifyHapg = Action('ModifyHapg')
ModifyHsm = Action('ModifyHsm')



# Example taken from AWS docs:
# http://docs.aws.amazon.com/AmazonECS/latest/developerguide/IAM_policies.html#instance_IAM_role

from awacs.aws import Allow
from awacs.aws import Policy, Statement
import awacs.ecs as ecs


pd = Policy(
    Statement=[
        Statement(
            Effect=Allow,
            Action=[ecs.CreateCluster, ecs.RegisterContainerInstance,
                    ecs.DeregisterContainerInstance, ecs.DiscoverPollEndpoint,
                    ecs.Action("Submit*"), ecs.Poll],
            Resource=["*"]
        )
    ]
)
print(pd.to_json())



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Directory Service'
prefix = 'ds'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateComputer = Action('CreateComputer')
CreateDirectory = Action('CreateDirectory')
CreateSnapshot = Action('CreateSnapshot')
CheckAlias = Action('CheckAlias')
ConnectDirectory = Action('ConnectDirectory')
DeleteDirectory = Action('DeleteDirectory')
DeleteSnapshot = Action('DeleteSnapshot')
DescribeDirectories = Action('DescribeDirectories')
DescribeSnapshots = Action('DescribeSnapshots')
GetDirectoryLimits = Action('GetDirectoryLimits')
GetSnapshotLimits = Action('GetSnapshotLimits')
ListAuthorizedApplications = Action('ListAuthorizedApplications')
RepairDirectory = Action('RepairDirectory')
RestoreFromSnapshot = Action('RestoreFromSnapshot')
UpdateDirectory = Action('UpdateDirectory')



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Simple Systems Manager'
prefix = 'ssm'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelCommand = Action('CancelCommand')
CreateAssociation = Action('CreateAssociation')
CreateAssociationBatch = Action('CreateAssociationBatch')
CreateDocument = Action('CreateDocument')
DeleteAssociation = Action('DeleteAssociation')
DeleteDocument = Action('DeleteDocument')
DescribeAssociation = Action('DescribeAssociation')
DescribeDocument = Action('DescribeDocument')
DescribeDocumentPermission = Action('DescribeDocumentPermission')
DescribeInstanceInformation = Action('DescribeInstanceInformation')
GetDocument = Action('GetDocument')
ListAssociations = Action('ListAssociations')
ListCommandInvocations = Action('ListCommandInvocations')
ListCommands = Action('ListCommands')
ListDocuments = Action('ListDocuments')
ModifyDocumentPermission = Action('ModifyDocumentPermission')
SendCommand = Action('SendCommand')
UpdateAssociationStatus = Action('UpdateAssociationStatus')



from awacs.aws import Statement, Principal, Allow, Policy
from awacs import sts


def make_simple_assume_statement(principal):
    return Statement(
        Principal=Principal('Service', [principal]),
        Effect=Allow,
        Action=[sts.AssumeRole])


def get_default_assumerole_policy(region=''):
    """ Helper function for building the Default AssumeRole Policy

    Taken from here:
        https://github.com/boto/boto/blob/develop/boto/iam/connection.py#L29
    Used to allow ec2 instances to assume the roles in their InstanceProfile.
    """

    service = 'ec2.amazonaws.com'
    if region == 'cn-north-1':
        service = 'ec2.amazonaws.com.cn'
    policy = Policy(
        Statement=[make_simple_assume_statement(service)]
    )
    return policy


def get_ecs_assumerole_policy(region=''):
    """ Helper function for building the ECS AssumeRole Policy
    """

    service = 'ecs.amazonaws.com'
    policy = Policy(
        Statement=[make_simple_assume_statement(service)]
    )
    return policy


def get_lambda_assumerole_policy(region=''):
    """ Helper function for building the ECS AssumeRole Policy
    """

    service = 'lambda.amazonaws.com'
    policy = Policy(
        Statement=[make_simple_assume_statement(service)]
    )
    return policy



# Copyright (c) 2012-2013, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Redshift'
prefix = 'redshift'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AuthorizeClusterSecurityGroupIngress = \
    Action('AuthorizeClusterSecurityGroupIngress')
AuthorizeSnapshotAccess = Action('AuthorizeSnapshotAccess')
CancelQuerySession = Action('CancelQuerySession')
CopyClusterSnapshot = Action('CopyClusterSnapshot')
CreateCluster = Action('CreateCluster')
CreateClusterParameterGroup = Action('CreateClusterParameterGroup')
CreateClusterSecurityGroup = Action('CreateClusterSecurityGroup')
CreateClusterSnapshot = Action('CreateClusterSnapshot')
CreateClusterSubnetGroup = Action('CreateClusterSubnetGroup')
CreateEventSubscription = Action('CreateEventSubscription')
CreateHsmClientCertificate = Action('CreateHsmClientCertificate')
CreateHsmConfiguration = Action('CreateHsmConfiguration')
CreateTags = Action('CreateTags')
DeleteCluster = Action('DeleteCluster')
DeleteClusterParameterGroup = Action('DeleteClusterParameterGroup')
DeleteClusterSecurityGroup = Action('DeleteClusterSecurityGroup')
DeleteClusterSnapshot = Action('DeleteClusterSnapshot')
DeleteClusterSubnetGroup = Action('DeleteClusterSubnetGroup')
DeleteEventSubscription = Action('DeleteEventSubscription')
DeleteHsmClientCertificate = Action('DeleteHsmClientCertificate')
DeleteHsmConfiguration = Action('DeleteHsmConfiguration')
DeleteTags = Action('DeleteTags')
DescribeClusterParameterGroups = Action('DescribeClusterParameterGroups')
DescribeClusterParameters = Action('DescribeClusterParameters')
DescribeClusterSecurityGroups = Action('DescribeClusterSecurityGroups')
DescribeClusterSnapshots = Action('DescribeClusterSnapshots')
DescribeClusterSubnetGroups = Action('DescribeClusterSubnetGroups')
DescribeClusterVersions = Action('DescribeClusterVersions')
DescribeClusters = Action('DescribeClusters')
DescribeDefaultClusterParameters = \
    Action('DescribeDefaultClusterParameters')
DescribeEventCategories = Action('DescribeEventCategories')
DescribeEventSubscriptions = Action('DescribeEventSubscriptions')
DescribeEvents = Action('DescribeEvents')
DescribeHsmClientCertificates = Action('DescribeHsmClientCertificates')
DescribeHsmConfigurations = Action('DescribeHsmConfigurations')
DescribeLoggingStatus = Action('DescribeLoggingStatus')
DescribeOrderableClusterOptions = \
    Action('DescribeOrderableClusterOptions')
DescribeReservedNodeOfferings = Action('DescribeReservedNodeOfferings')
DescribeReservedNodes = Action('DescribeReservedNodes')
DescribeResize = Action('DescribeResize')
DescribeTags = Action('DescribeTags')
DisableLogging = Action('DisableLogging')
DisableSnapshotCopy = Action('DisableSnapshotCopy')
EnableLogging = Action('EnableLogging')
EnableSnapshotCopy = Action('EnableSnapshotCopy')
ModifyCluster = Action('ModifyCluster')
ModifyClusterParameterGroup = Action('ModifyClusterParameterGroup')
ModifyClusterSubnetGroup = Action('ModifyClusterSubnetGroup')
ModifyEventSubscription = Action('ModifyEventSubscription')
ModifySnapshotCopyRetentionPeriod = \
    Action('ModifySnapshotCopyRetentionPeriod')
PurchaseReservedNodeOffering = Action('PurchaseReservedNodeOffering')
RebootCluster = Action('RebootCluster')
ResetClusterParameterGroup = Action('ResetClusterParameterGroup')
RestoreFromClusterSnapshot = Action('RestoreFromClusterSnapshot')
RevokeClusterSecurityGroupIngress = \
    Action('RevokeClusterSecurityGroupIngress')
RevokeSnapshotAccess = Action('RevokeSnapshotAccess')
RotateEncryptionKey = Action('RotateEncryptionKey')
ViewQueriesInConsole = Action('ViewQueriesInConsole')
